/*
 * $Id: OrderDAOCS.java,v 1.6 2000/10/04 22:00:17 brydon Exp $
 * Copyright 2000 Sun Microsystems, Inc. All rights reserved.
 * Copyright 2000 Sun Microsystems, Inc. Tous droits rservs.
 */

package com.sun.j2ee.blueprints.customer.order.ejb;

import java.util.Collection;
import java.util.Iterator;
import java.text.NumberFormat;
import java.text.DecimalFormat;
import java.sql.Connection;
import java.sql.Statement;
import java.sql.ResultSet;
import java.sql.SQLException;

import com.sun.j2ee.blueprints.customer.util.Debug;
import com.sun.j2ee.blueprints.customer.util.DatabaseNames;
import com.sun.j2ee.blueprints.customer.util.Address;
import com.sun.j2ee.blueprints.customer.order.model.LineItem;
import com.sun.j2ee.blueprints.customer.order.ejb.OrderDAOException;

/**
 * This class represents the implementation of the
 * abstract methods of the base class OrderDAO for
 * Cloudscape.
 *
 * @see UUIDGenerator
 */
public class OrderDAOCS extends OrderDAO {


    public OrderDAOCS() throws OrderDAOException {
        super();
    }

    /**
     * part of the OrderDAO abstract class
     */
    public void create() throws OrderDAOException {
        getUniqueOrderId();
        insertOrder(orderId);
        insertLineItem(orderId);
        insertOrderStatus(orderId);
    }

    private void getUniqueOrderId() throws OrderDAOException {
        try {
            getDBConnection();
            orderId = UUIDGenerator.nextSeqNum(dbConnection);
        } catch(OrderDAOException se) {
            throw new OrderDAOException("SQLException while getting " +
                    "order ID : \n" + se);
        } finally {
            closeConnection();
        }
    }

    /**
     * part of the OrderDAO abstract class
     */
    public void store() throws OrderDAOException {
        updateOrder();
        updateLineItem();
        updateOrderStatus();
    }

    private void insertOrder(int OrderId) throws OrderDAOException {
        if (!isValidData())
            throw new OrderDAOException("Illegal data values for insert");

        String queryStr = "INSERT INTO " + DatabaseNames.ORDER_TABLE
            + "(orderid,userid,orderdate,"
            + "shipaddr1,shipaddr2,shipcity,shipstate,shipzip,shipcountry,"
            + "billaddr1,billaddr2,billcity,billstate,billzip,billcountry,"
            + "courier,totalprice,"
            + "shiptofirstname,shiptolastname,"
            + "billtofirstname,billtolastname,"
            + "creditcard,exprdate,cardtype)" + "VALUES ("
            +  orderId + ","
            + "'" + userId.trim()  + "',"
            +  "'" + orderDate.getCloudscapeDateString() + "',"
            + "'"+shipToAddr.getStreetName1().trim() +"',";

        if (shipToAddr.getStreetName2() != null)
            queryStr += "'"+shipToAddr.getStreetName2().trim() +"',";
        else
            queryStr += "' ',";

        queryStr +=  "'"+shipToAddr.getCity().trim() + "',"
            + "'"+shipToAddr.getState().trim() + "',"
            + "'"+shipToAddr.getZipCode().trim() + "',"
            + "'"+shipToAddr.getCountry().trim() + "',"
            + "'"+billToAddr.getStreetName1().trim() +"',";

        if (billToAddr.getStreetName2() != null)
            queryStr += "'"+shipToAddr.getStreetName2().trim() +"',";
        else
            queryStr += "' ',";

        queryStr += "'"+billToAddr.getCity().trim() + "',"
            + "'"+billToAddr.getState().trim() + "',"
            + "'"+billToAddr.getZipCode().trim() + "',"
            + "'"+billToAddr.getCountry().trim() + "',"
            + "'"+carrier.trim() + "',"
            + totalPrice + ","
            + "'"+shipToFirstName.trim() + "',"
            + "'"+shipToLastName.trim() + "',"
            + "'"+billToFirstName.trim() + "',"
            + "'"+billToLastName.trim() + "',"
            + "'"+chargeCard.getCardNo().trim() + "',"
            + "'"+chargeCard.getExpiryDateString().trim() + "',"
            + "'"+chargeCard.getCardType().trim() + "' )";
        Debug.println("queryString is: "+ queryStr);

        try {
            getDBConnection();
            Statement stmt = dbConnection.createStatement();
            int resultCount = stmt.executeUpdate(queryStr);

            if ( resultCount != 1 )
                throw new OrderDAOException(
                    "ERROR in ORDER_TABLE INSERT !! resultCount = "
                        + resultCount);
        } catch(SQLException se) {
            throw new OrderDAOException("SQLException while inserting " +
                    "order " + orderId + " : \n" + se);
        } finally {
            closeConnection();
        }
    }

    private void insertLineItem(int orderId) throws OrderDAOException {
        LineItem LI;
        int resultCount;

        try {
            getDBConnection();
            Statement stmt = dbConnection.createStatement();
            for (Iterator it = lineItems.iterator() ; it.hasNext() ;) {
                LI = (LineItem) it.next();
                if (LI == null)
                    throw new OrderDAOException("LineItem is null");
                String queryStr = "INSERT INTO "
                    + DatabaseNames.LINE_ITEM_TABLE
                    + "(orderid,linenum,itemid,quantity,unitprice) VALUES ("
                    + orderId + ","
                    + LI.getLineNo() + ","
                    + "'"+ LI.getItemNo().trim() + "',"
                    + LI.getQty() + ","
                    + LI.getUnitPrice() + ")";
                Debug.println("queryString is: "+ queryStr);
                resultCount = stmt.executeUpdate(queryStr);
                if ( resultCount != 1 )
                    throw new OrderDAOException
                        ("ERROR in LINE_ITEM_TABLE INSERT !! resultCount = "
                            + resultCount);
            }
        } catch(SQLException se) {
            throw new OrderDAOException("SQLException while inserting " +
                    "line item for order " + orderId + " : \n" + se);
        } finally {
            closeConnection();
        }
    }

    private void insertOrderStatus(int orderId) throws OrderDAOException {

        try {
            getDBConnection();
            int lineNum = UUIDGenerator.nextSeqNum(dbConnection);
            Statement stmt = dbConnection.createStatement();
            String queryStr = "INSERT INTO "
                + DatabaseNames.ORDER_STATUS_TABLE
                + "(orderid,linenum,updatedate,status) VALUES ("
                + orderId + ","
                + lineNum + ","
                + " current_date,"
                + "'" + status.trim() + "')";
            Debug.println("queryString is: "+ queryStr);
            int resultCount = stmt.executeUpdate(queryStr);
            if ( resultCount != 1 )
                throw new OrderDAOException
                    ("ERROR in ORDER_STATUS_TABLE INSERT !! resultCount = "
                        + resultCount);
        } catch(SQLException se) {
            throw new OrderDAOException("SQLException while inserting " +
                    "order status : \n" + se);
        } finally {
            closeConnection();
        }
    }

    private void updateOrder() throws OrderDAOException {
        String queryStr = "UPDATE " + DatabaseNames.ORDER_TABLE
            + " SET userid = " + "'" + userId.trim() + "',"
            + "orderdate = " + "'" + orderDate.getCloudscapeDateString()+ "',"
            + "shipaddr1 = " + "'" + shipToAddr.getStreetName1().trim() + "',";

        if (shipToAddr.getStreetName2() != null)
            queryStr += "shipaddr2 = " + "'"
                    + shipToAddr.getStreetName2().trim() + "',";
        else
            queryStr += "shipaddr2 = ' ',";

        queryStr += "shipcity = " + "'" + shipToAddr.getCity().trim() + "',"
            + "shipstate = " + "'" + shipToAddr.getState().trim() + "',"
            + "shipzip = " + "'" + shipToAddr.getZipCode().trim() + "',"
            + "shipcountry = " + "'" + shipToAddr.getCountry().trim() + "',"
            + "billaddr1 = " + "'" + billToAddr.getStreetName1().trim() + "',";

        if (billToAddr.getStreetName2() != null)
            queryStr += "billaddr2 = " + "'"
                + billToAddr.getStreetName2().trim() + "',";
        else
            queryStr += "billaddr2 = ' ',";

        queryStr +=  "billcity = " + "'" + billToAddr.getCity().trim() + "',"
            + "billstate = " + "'" + billToAddr.getState().trim() + "',"
            + "billzip = " + "'" + billToAddr.getZipCode().trim() + "',"
            + "billcountry = " + "'" + billToAddr.getCountry().trim() + "',"
            + "courier = " + "'" + carrier.trim() + "',"
            + "totalprice = " + formatPrice(totalPrice) + ","
            + "shiptofirstname = " + "'" + shipToFirstName.trim() + "',"
            + "shiptolastname = " + "'" + shipToLastName.trim() + "',"
            + "billtofirstname = " + "'" + billToFirstName.trim() + "',"
            + "billtolastname = " + "'" + billToLastName.trim() + "',"
            + "creditcard = " + "'" + chargeCard.getCardNo().trim() + "',"
            + "exprdate = " + "'" + chargeCard.getExpiryDateString().trim() + "',"
            + "cardtype = " + "'" + chargeCard.getCardType().trim()+ "'"
            + " WHERE orderid = " + orderId;
        Debug.println("queryString is: "+ queryStr);

        try {
            getDBConnection();
            Statement stmt = dbConnection.createStatement();
            int resultCount = stmt.executeUpdate(queryStr);
            if ( resultCount != 1 )
                throw new OrderDAOException
                    ("ERROR updating order in ORDER_TABLE!! resultCount = " +
                             resultCount);
        } catch(SQLException se) {
            throw new OrderDAOException("SQLException while updating " +
                    "order : \n" + se);
        } finally {
            closeConnection();
        }
    }

    private String formatPrice(double price){
        NumberFormat nf = NumberFormat.getInstance();
        DecimalFormat df = (DecimalFormat)nf;
        df.setMinimumFractionDigits(2);
        df.setMaximumFractionDigits(2);
        String pattern = "##.00";
        df.applyPattern(pattern);
        df.setDecimalSeparatorAlwaysShown(true);
        return df.format(price);
    }

    private void updateLineItem() throws OrderDAOException {
        LineItem LI;
        int resultCount;

        try {
            getDBConnection();
            Statement stmt = dbConnection.createStatement();
            for (Iterator it = lineItems.iterator() ; it.hasNext() ;) {
                LI = (LineItem) it.next();
                if (LI == null)
                    throw new OrderDAOException("LineItem is null");
                String queryStr = "UPDATE "+ DatabaseNames.LINE_ITEM_TABLE
                    + " SET itemid = " + "'"+ LI.getItemNo().trim() + "',"
                    + "quantity = " + LI.getQty() + ","
                    + "unitprice = " + LI.getUnitPrice()
                    + " WHERE orderid = " + orderId
                    + " AND linenum = " + LI.getLineNo();
                Debug.println("queryString is: "+ queryStr);

                resultCount = stmt.executeUpdate(queryStr);
                if ( resultCount != 1 )
                    throw new OrderDAOException
                        ("ERROR updating LINE_ITEM_TABLE  !! resultCount = "
                                + resultCount);
            }
        } catch(SQLException se) {
            throw new OrderDAOException("SQLException while updating " +
                    "line item : \n" + se);
        } finally {
            closeConnection();
        }
    }

    private void updateOrderStatus() throws OrderDAOException {

        try {
            getDBConnection();
            Statement stmt = dbConnection.createStatement();
            String queryStr = "UPDATE " + DatabaseNames.ORDER_STATUS_TABLE
                + " SET status = " + "'"+ status.trim() + "'"
                + " WHERE orderid = " + orderId;
            Debug.println("queryString is: "+ queryStr);
            int resultCount = stmt.executeUpdate(queryStr);
            if ( resultCount != 1 )
                throw new OrderDAOException
                    ("ERROR updating ORDER_STATUS_TABLE !! resultCount = "
                            + resultCount);
        } catch(SQLException se) {
            throw new OrderDAOException("SQLException while updating " +
                    "order status : \n" + se);
        } finally {
            closeConnection();
        }
    }
}
