/*
 * $Id: InventoryDAO.java,v 1.10 2000/10/03 04:07:49 brydon Exp $
 * Copyright 2000 Sun Microsystems, Inc. All rights reserved.
 * Copyright 2000 Sun Microsystems, Inc. Tous droits rservs.
 */

package com.sun.j2ee.blueprints.inventory.ejb;

import java.rmi.RemoteException;
import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import javax.sql.DataSource;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.naming.Context;

import com.sun.j2ee.blueprints.inventory.util.Debug;
import com.sun.j2ee.blueprints.inventory.util.DatabaseNames;
import com.sun.j2ee.blueprints.inventory.util.JNDINames;

/**
 * This class encapsulates all the JDBC calls made by
 * the InventoryEJB. The actual logic of inserting,
 * fetching, updating, or deleting  the data in
 * relational database tables to mirror the state of
 * InventoryEJB is implemented here.
 */
public class InventoryDAO {

    private String itemId;
    private int qty;

    private Connection dbConnection = null;
    private DataSource datasource   = null;

    public InventoryDAO() throws InventoryDAOException {
        try {
            InitialContext ic = new InitialContext();
            datasource = (DataSource)
            ic.lookup(JNDINames.INVENTORY_DATASOURCE);
        } catch (NamingException ne) {
            throw new InventoryDAOException("NamingException while looking" +
                                               " up DataSource Connection " +
                                             JNDINames.INVENTORY_DATASOURCE +
                                                       ": \n" + ne.getMessage());
        }
    }

    // get and set methods for the instance variables

    public String getItemId(){
        return itemId;
    }
    public int getQuantity() {
        return qty;
    }
    public void setItemId( String itemId) {
        this.itemId = itemId;
    }
    public void setQuantity(int qty) {
        this.qty = qty;
    }
    public void load () throws InventoryDAOException {
        selectInventory();
    }
    public void store() throws InventoryDAOException {
        updateInventory();
    }
    public void remove() throws InventoryDAOException {
        deleteInventory();
    }
    public String findByPrimaryKey() throws InventoryDAOException {
        if (itemExists(itemId))
            return (itemId);
        throw new InventoryDAOException ("Primary key not found; Item Id = " +
                                                    itemId);
    }
    private boolean itemExists(String itemId) throws InventoryDAOException {
        getConnection();
        String queryStr ="SELECT itemid FROM " +
                DatabaseNames.INVENTORY_TABLE +
                        " WHERE itemid = " + "'" + itemId.trim() + "'";
        Debug.println("queryString is: "+ queryStr);

        try {
            Statement stmt = dbConnection.createStatement();
            ResultSet result = stmt.executeQuery(queryStr);
            if ( !result.next() ) {
                return false;
            } else {
                itemId = result.getString(1);
                return true;
            }
        } catch(SQLException se) {
            throw new InventoryDAOException("Unable to Query for item " + itemId +
                                        "\n" + se);
        } finally {
            closeConnection();
        }
    }

    private boolean isValidData () {
        if ( (itemId == null) )
            return (false);
        else
            return (true);
    }

    private void selectInventory () throws InventoryDAOException {
        getConnection();
        String queryStr = "SELECT "+
            "itemid, qty "+
                " FROM " + DatabaseNames.INVENTORY_TABLE + " WHERE itemid = "
                    + "'" + itemId.trim() + "'";
        Debug.println("queryString is: "+ queryStr);

        try {
            Statement stmt = dbConnection.createStatement();
            ResultSet result = stmt.executeQuery(queryStr);
            if(!result.next())
                throw new InventoryDAOException("No record for primary key " +
                                   itemId);
            int i = 1;
            itemId = result.getString(i++);
            qty = result.getInt(i++);
        } catch(SQLException se) {
            throw new InventoryDAOException("Unable to Query for item " + itemId +
                                        "\n" + se);
        } finally {
            closeConnection();
        }
    }

    private void deleteInventory () throws InventoryDAOException {
        getConnection();
        String queryStr = "DELETE FROM " + DatabaseNames.INVENTORY_TABLE +
                " WHERE itemid = "
                    + "'" + itemId.trim() + "'";
        Debug.println("queryString is: "+ queryStr);
        try {
            Statement stmt = dbConnection.createStatement();
            int resultCount = stmt.executeUpdate(queryStr);
            if ( resultCount != 1 )
                throw new InventoryDAOException("ERROR deleteing inventory from" +
                        " INVENTORY_TABLE!! resultCount = " + resultCount);
        } catch(SQLException se) {
            throw new InventoryDAOException("Unable to delete for item " + itemId +
                                        "\n" + se);
        } finally {
            closeConnection();
        }
    }


    private void updateInventory () throws InventoryDAOException {
        getConnection();
        if (!isValidData())
            throw new InventoryDAOException ("Illegal data values for update");
        try {
            Statement stmt = dbConnection.createStatement();
            String queryStr = "UPDATE " + DatabaseNames.INVENTORY_TABLE
                + " SET " + "qty = " +  qty
                    + " WHERE itemid = " + "'" + itemId.trim() + "'";
            Debug.println("queryString is: "+ queryStr);
            int resultCount = stmt.executeUpdate(queryStr);
            if ( resultCount != 1 )
                throw new InventoryDAOException ("ERROR updating inventory in" +
                    " INVENTORY_TABLE!! resultCount = " + resultCount);
        } catch(SQLException se) {
            throw new InventoryDAOException("Unable to update item " + itemId +
                        " \n" + se);
        } finally {
            closeConnection();
        }
    }

    private void getConnection() throws InventoryDAOException {
        try {
            dbConnection = datasource.getConnection();
        } catch (SQLException se) {
            throw new InventoryDAOException("SQLExcpetion while getting" +
                                        " DB Connection : \n" + se);
        }
    }

    private void closeConnection() throws InventoryDAOException {
        try {
            if (dbConnection != null && !dbConnection.isClosed()) {
                dbConnection.close();
            }
        } catch (SQLException se) {
            throw new InventoryDAOException("SQLExcpetion while closing" +
                                    " DB Connection : \n" + se);
        }
    }
}
