package com.sun.j2ee.blueprints.mail.ejb;


import java.util.Date;

import javax.activation.DataHandler;
import javax.ejb.SessionContext;
import javax.mail.Message;
import javax.mail.MessagingException;
import javax.mail.Transport;
import javax.mail.Session;
import javax.mail.internet.MimeMessage;
import javax.mail.internet.InternetAddress;
import javax.naming.InitialContext;

import com.sun.j2ee.blueprints.mail.util.Debug;
import com.sun.j2ee.blueprints.mail.util.JNDINames;
import com.sun.j2ee.blueprints.mail.ejb.SendMailException;

/**
 * A helper class to create and send mail.
 */
public class MailHelper {


    /**
     * This method creates an email message and sends it using the
     * J2EE mail services
     * @param to           indended recipient of the email message
     * @param subject      the subject line of the email message
     * @param htmlContents contents of the email message
     */
    public void createAndSendMail(EMailMessage eMess) throws SendMailException {
        try {
            Debug.println("Sending message" +
                          "\nTo: " + eMess.getEmailReceiver() +
                          "\nSubject: " + eMess.getSubject() +
                          "\nContents: " + eMess.getHtmlContents());

            InitialContext ic = new InitialContext();
            Session session = (Session) ic.lookup(JNDINames.MAIL_SESSION);


            if (Debug.debuggingOn)
                session.setDebug(true);

            // construct the message
            Message msg = new MimeMessage(session);
            msg.setFrom();

            msg.setRecipients(Message.RecipientType.TO,
                     InternetAddress.parse(eMess.getEmailReceiver(), false));

            msg.setSubject(eMess.getSubject());

            msg.setContent(eMess.getHtmlContents(), "text/plain");

            msg.setHeader("X-Mailer", "JavaMailer");
            msg.setSentDate(new Date());

            // send the mail off
            Transport.send(msg);

            Debug.println("\nMail sent successfully.");
        } catch (Exception e) {
            Debug.print("createAndSendMail exception : " + e);
            throw new SendMailException();
        }
    }
}
