package com.sun.j2ee.blueprints.petstore.control.web;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;
import javax.servlet.ServletContext;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Locale;

import com.sun.j2ee.blueprints.util.tracer.Debug;
import com.sun.j2ee.blueprints.petstore.util.WebKeys;

import com.sun.j2ee.blueprints.petstore.control.web.handlers.FlowHandler;

/**
 * This file looks at the Request URL and maps the request
 * to the page for the web-templating mechanism.
 */
public class ScreenFlowManager {

    private HashMap screens;
    private HashMap urlMappings;
    private HashMap screenDefinitionMappings;
    private String defaultScreen = "MAIN";


    public ScreenFlowManager(){
        screens = new HashMap();
    }

    public void init(ServletContext context) {
        String screenDefinitionsURL = null;
        String requestMappingsURL = null;
        try {
            requestMappingsURL = context.getResource("/xml/requestmappings.xml").toString();
        } catch (java.net.MalformedURLException ex) {
            Debug.println("ScreenFlowManager: initializing ScreenFlowManager malformed URL exception: " + ex);
        }
        // get preferred local here and load the preferred languaqe accordingly
        screenDefinitionMappings = ScreenFlowXmlDAO.loadScreenDefinitionMappings(requestMappingsURL);
        Iterator it = screenDefinitionMappings.keySet().iterator();
        while (it.hasNext()) {
            String language = (String)it.next();
            Debug.println("ScreenFlowManager loading screen definitions for language " + language);
            try {
                String mappings = (String)screenDefinitionMappings.get(language);
                Debug.println("ScreenFlowManager: mappings are: " + mappings);
                screenDefinitionsURL = context.getResource(mappings).toString();
            } catch (java.net.MalformedURLException ex) {
                Debug.println("ScreenFlowManager: initializing ScreenFlowManager malformed URL exception: " + ex);
            }
            HashMap screenDefinitions = ScreenFlowXmlDAO.loadScreenDefinitions(screenDefinitionsURL);
            screens.put(language, screenDefinitions);
            urlMappings = ScreenFlowXmlDAO.loadRequestMappings(requestMappingsURL);
        }

        Debug.println("ScreenFlowManager:  initialized Screens and URL mappings");
    }
    /**
        Get the screens for the specified language.

    */

    public HashMap getScreens(Locale locale) {
        String languageKey = locale.getLanguage() + "_" + locale.getCountry();
        if (screens.containsKey(languageKey)) {
            return (HashMap)screens.get(languageKey);
        }
        return null;
    }

    /**
        Get the template for the specified language.

    */
    public String getTemplate(Locale locale) {
        HashMap localeScreens = getScreens(locale);
        if (localeScreens == null) return null;
        else return (String)localeScreens.get(ScreenFlowXmlDAO.TEMPLATE);
    }

    /**
     * The UrlMapping object contains information that will match
     * a url to a mapping object that contains information about
     * the current screen, the RequestHandler that is needed to
     * process a request, and the RequestHandler that is needed
     * to insure that the propper screen is displayed.
    */

    public URLMapping getURLMapping(String urlPattern) {
        if ((urlMappings != null) && urlMappings.containsKey(urlPattern)) {
            return (URLMapping)urlMappings.get(urlPattern);
        } else {
            return null;
        }
    }

    /**
     * Using the information we have in the request along with
     * The url map for the current url we will insure that the
     * propper current screen is selected based on the settings
     * in both the screendefinitions.xml file and requestmappings.xml
     * files.
    */
    public void getNextScreen(HttpServletRequest request) {
        String selectedURL = request.getPathInfo();
        String currentScreen = defaultScreen;
        URLMapping urlMapping = getURLMapping(selectedURL);
        if (urlMapping != null) {
            if (!urlMapping.useFlowHandler()) {
                currentScreen = urlMapping.getScreen();
            } else {
                Debug.println("ScreenFlowManager: using flow handler for:" + selectedURL);
                // load the flow handler
                FlowHandler handler = null;
                String flowHandlerString = urlMapping.getFlowHandler();
                try {
                    handler = (FlowHandler)getClass().getClassLoader().loadClass(flowHandlerString).newInstance();
                    // cache the handler?
                    // invoke the processFlow(HttpServletRequest)
                    handler.doStart(request);
                    String flowResult = handler.processFlow(request);
                    Debug.println("ScreenFlowManager: flow handler processing result=" + flowResult);
                    handler.doEnd(request);
                    // get the matching screen from the URLMapping object
                    currentScreen = urlMapping.getResultScreen(flowResult);
               } catch (Exception ex) {
                   Debug.println("ScreenFlowManager caught loading handler: " + ex);
               }
            }
        }
        request.getSession().setAttribute(WebKeys.CurrentScreen, currentScreen);
    }

    public void setDefaultScreen(String defaultScreen) {
        this.defaultScreen = defaultScreen;
    }

    /**
    * Gets the required parameter for the current screen
    *
    * This method is used by the insert tag to get the parameters
    * needed to build a page.
    *
    * If a language is not set then the default properties will be loaded.
    */
    public Parameter getParameter(String key, HttpSession session) {
        String currentScreen = (String)session.getAttribute(WebKeys.CurrentScreen);
        Locale locale = (Locale)session.getAttribute(WebKeys.LanguageKey);
        if (locale == null) locale = Locale.US;
        if (currentScreen == null) currentScreen = defaultScreen;
        if (screens == null || currentScreen == null) return null;
        Screen screen = (Screen)getScreens(locale).get(currentScreen);
        if (screen == null) {
            return null;
        }
        return screen.getParameter(key);
    }

    public String getCurrentScreen(HttpSession session)  {
        return (String)session.getAttribute(WebKeys.CurrentScreen);
    }

}

